handlertools
============

.. automodule:: abjad.tools.handlertools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.handlertools.ArticulationHandler.ArticulationHandler
      ~abjad.tools.handlertools.DynamicHandler.DynamicHandler
      ~abjad.tools.handlertools.Handler.Handler

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.handlertools.DiatonicClusterHandler.DiatonicClusterHandler
      ~abjad.tools.handlertools.NoteAndChordHairpinHandler.NoteAndChordHairpinHandler
      ~abjad.tools.handlertools.NoteAndChordHairpinsHandler.NoteAndChordHairpinsHandler
      ~abjad.tools.handlertools.OctaveTranspositionHandler.OctaveTranspositionHandler
      ~abjad.tools.handlertools.OverrideHandler.OverrideHandler
      ~abjad.tools.handlertools.PatternedArticulationsHandler.PatternedArticulationsHandler
      ~abjad.tools.handlertools.ReiteratedArticulationHandler.ReiteratedArticulationHandler
      ~abjad.tools.handlertools.ReiteratedDynamicHandler.ReiteratedDynamicHandler
      ~abjad.tools.handlertools.RepeatedMarkupHandler.RepeatedMarkupHandler
      ~abjad.tools.handlertools.RestTerminatedMantenimentiHandler.RestTerminatedMantenimentiHandler
      ~abjad.tools.handlertools.StemTremoloHandler.StemTremoloHandler
      ~abjad.tools.handlertools.TerracedDynamicsHandler.TerracedDynamicsHandler
      ~abjad.tools.handlertools.TimewisePitchClassHandler.TimewisePitchClassHandler
      ~abjad.tools.handlertools.TwoStageHairpinHandler.TwoStageHairpinHandler
